@@ -10,8 +10,8 @@ class Persons(object):
         url = 'persons'
         return self._client._get(self._client.BASE_URL + url, params=params, **kwargs)
 
-    def get_persons_by_name(self, params=None, **kwargs):
-        url = 'persons/find'
+    def search_persons(self, params=None, **kwargs):
+        url = 'persons/search'
         return self._client._get(self._client.BASE_URL + url, params=params, **kwargs)
 
     def create_person(self, data, **kwargs):
@@ -24,7 +24,7 @@ class Persons(object):
 
     def delete_person(self, person_id, **kwargs):
         url = 'persons/{}'.format(person_id)
-        return self._client._delete(url, **kwargs)
+        return self._client._delete(self._client.BASE_URL + url, **kwargs)
 
     def get_person_deals(self, person_id, **kwargs):
         url = 'persons/{}/deals'.format(person_id)
@@ -32,4 +32,4 @@ class Persons(object):
 
     def get_person_fields(self, params=None, **kwargs):
         url = 'personFields'
-        return self._client._get(self._client.BASE_URL + url, params=params, **kwargs)
+        return self._client._get(self._client.BASE_URL + url, params=params, **kwargs)
\ No newline at end of file
