@@ -10,9 +10,9 @@ class Products(object):
         url = 'products'
         return self._client._get(self._client.BASE_URL + url, **kwargs)
 
-    def get_product_by_name(self, **kwargs):
-        url = 'products/find'
-        return self._client._get(self._client.BASE_URL + url, **kwargs)
+    def search_products(self, params=None, **kwargs):
+        url = 'products/search'
+        return self._client._get(self._client.BASE_URL + url, params=params, **kwargs)
 
     def create_product(self, data, **kwargs):
         url = 'products'
